@@ -32,8 +32,7 @@
 #include "enumerations.h"
 #include "layout-block.h"
 
-enum
-{
+enum {
 	PROP_0,
 	PROP_TITLE,
 	PROP_POS_X,
@@ -51,8 +50,7 @@ enum
 	PROP_FONT_SIZE
 };
 
-enum
-{
+enum {
 	SIGNAL,
 	N_SIGNALS
 };
@@ -72,8 +70,7 @@ static	void	cria_layout_block_signal       (CriaLayoutBlock	* template,
 						const	gchar	* string);
 
 static void
-cria_layout_block_class_init (CriaLayoutBlockClass	* cria_layout_block_class)
-{
+cria_layout_block_class_init (CriaLayoutBlockClass* cria_layout_block_class) {
 	GObjectClass	* g_object_class;
 
 	g_object_class = G_OBJECT_CLASS(cria_layout_block_class);
@@ -733,7 +730,7 @@ cria_layout_block_set_title (
 
 	self->title = g_strdup (title);
 
-	g_debug ("cria_layout_block_set_title(): title ox%x", (guint) self->title);
+	g_debug ("cria_layout_block_set_title(): title 0x%x", (guint) self->title);
 	g_object_notify (G_OBJECT (self), "title");
 }
 
@@ -854,3 +851,4 @@ cria_valignment_from_string (char const * string)
 #warning implement stub method
 	return CRIA_ALIGNMENT_TOP;
 }
+
