@@ -48,8 +48,10 @@ CriaTheme	* cria_presentation_get_theme	       (CriaPresentation* self,
 const gchar	* cria_presentation_get_title	       (CriaPresentation* self);
 guint		  cria_presentation_n_slides	       (CriaPresentation*self);
 CriaPresentation* cria_presentation_new		       (void);
-CriaPresentation* cria_presentation_new_from_file      (const	gchar	* filename);
-CriaPresentation* cria_presentation_new_from_uri       (const gchar	* text_uri);
+CriaPresentation* cria_presentation_new_from_file      (const	gchar	* filename,
+							GError		**error);
+CriaPresentation* cria_presentation_new_from_uri       (const gchar	* text_uri,
+							GError		**error);
 void		  cria_presentation_set_title	       (CriaPresentation* self,
 							const char	* attribute);
 void		  cria_presentation_add_master_slide   (CriaPresentation* self,
