@@ -24,6 +24,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include "debug.h"
@@ -39,13 +40,6 @@ enum {
 	N_SIGNALS
 };
 
-enum {
-	COLUMN_PREVIEW,
-	COLUMN_TITLE,
-	COLUMN_INDEX,
-	N_COLUMNS
-};
-
 struct _CriaSlideListPrivate {
 	CriaPresentation	* presentation;
 	GtkTreeStore		* store;
@@ -200,7 +194,7 @@ cria_slide_list_init(CriaSlideList *self) {
 			COLUMN_TITLE);
 	gtk_tree_view_column_set_title(
 			column,
-			"Slides");
+			_("Slides"));
 	gtk_tree_view_append_column(
 			GTK_TREE_VIEW(self),
 			column);
