@@ -35,6 +35,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtkgesture.h>
 
+#include "application.h"
 #include "debug.h"
 #include "slide-show.h"
 
@@ -367,8 +368,10 @@ cria_slide_show_init (CriaSlideShow *self)
 			PACKAGE_DATA_DIR "/pixmaps/criawips.png",
 			&error);
 	if (error) {
-		g_message (_("Couldn't set window icon, you have to live without; reason: %s"), error->message);
+		gchar	* message = g_strdup_printf(_("Couldn't set window icon, you have to live without; reason: %s"), error->message);
+		cria_application_show_error_dialog(NULL, _("Error"), message);
 		g_error_free (error);
+		g_free(message);
 	}
 
 	gtk_window_fullscreen (GTK_WINDOW (self));
@@ -494,8 +497,7 @@ cria_slide_show_render_after_show (CriaSlideShow *self)
 }
 
 static void
-cria_slide_show_render_slide (CriaSlideShow *self)
-{
+cria_slide_show_render_slide (CriaSlideShow *self) {
 	gchar		* title;
 	CriaLayout	* layout;
 	CriaPresentation* presentation;
@@ -508,8 +510,8 @@ cria_slide_show_render_slide (CriaSlideShow *self)
 
 	presentation	= cria_slide_show_get_presentation (self);
 	slide		= cria_presentation_get_slide (presentation, self->slide);
-	theme 		= cria_presentation_get_theme (presentation, cria_slide_get_theme (slide));
-	layout		= cria_theme_get_layout (theme, cria_slide_get_layout (slide));
+	theme 		= cria_slide_get_theme (slide);
+	layout		= cria_slide_get_layout (slide);
 	// hmmm... these long lines make me want to write this in java
 
 	g_debug ("cria_slide_show_render_slide(): theme=0x%x layout=0x%x", (guint)theme, (guint)layout);
