@@ -28,6 +28,8 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 
+#include <gnome-canvas-helpers.h>
+
 #include "debug.h"
 #include "layout.h"
 #include "presentation.h"
@@ -207,6 +209,15 @@ cria_slide_view_get_property (GObject* object, guint prop_id, GValue* value, GPa
 	}
 }
 
+gdouble
+cria_slide_view_get_zoom(CriaSlideView* self) {
+	g_assert(self != NULL);
+	g_assert(CRIA_IS_SLIDE_VIEW(self));
+	g_assert(self->priv != NULL);
+
+	return self->priv->zoom;
+}
+
 GType
 cria_slide_view_get_type (void) {
 	static GType	type = 0;
@@ -356,13 +367,18 @@ cria_slide_view_set_property (
 
 void
 cria_slide_view_set_zoom(CriaSlideView* self, gdouble zoom) {
+	g_assert(self != NULL);
 	g_assert(G_IS_OBJECT(self));
 	g_assert(CRIA_IS_SLIDE_VIEW(self));
+	g_assert(self->priv != NULL);
+	g_assert(self->priv->canvas != NULL);
+	g_assert(GNOME_IS_CANVAS(self->priv->canvas));
+	g_assert(zoom > GNOME_CANVAS_EPSILON);
 
 	if(self->priv->zoom != zoom) {
 		self->priv->zoom = zoom;
 
-		gnome_canvas_set_pixels_per_unit(GNOME_CANVAS(self->priv->canvas), zoom);
+		gnome_canvas_set_zoom(GNOME_CANVAS(self->priv->canvas), zoom);
 		
 		g_object_notify(G_OBJECT(self), "zoom");
 		g_signal_emit_by_name(G_OBJECT(self), "zoom-changed");
@@ -560,13 +576,12 @@ cria_slide_view_render_block(CriaSlideView* self, CriaSlide* slide, gchar const*
 		c_item = gnome_canvas_item_new (self->priv->group,
 						gnome_canvas_text_get_type (),
 						"anchor", anchor,
-						"clip", TRUE,
+						//"clip", TRUE,
 						"clip-height", height,
 						"clip-width", width,
 						"family", cria_layout_block_get_font_family (cria_layout_get_block (layout, blockname)),
 						"fill-color", "black",
 						"justification", justification,
-						"size-points", font_size,
 						"size-set", TRUE,
 						"markup", cria_slide_block_get_processed_content (cria_slide_get_block (slide, blockname)),
 						// TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length)
@@ -586,13 +601,12 @@ cria_slide_view_render_block(CriaSlideView* self, CriaSlide* slide, gchar const*
 		c_item = gnome_canvas_item_new (self->priv->group,
 						gnome_canvas_text_get_type (),
 						"anchor", anchor,
-						"clip", TRUE,
+//						"clip", TRUE,
 						"clip-height", height,
 						"clip-width", width,
 						"family", cria_layout_block_get_font_family (cria_layout_get_block (layout, blockname)),
 						"fill-color", "black",
 						"justification", justification,
-						"size-points", font_size,
 						"size-set", TRUE,
 						"text", text,
 //						"weight", PANGO_WEIGHT_BOLD,
@@ -602,6 +616,7 @@ cria_slide_view_render_block(CriaSlideView* self, CriaSlide* slide, gchar const*
 						"y", y,
 						NULL);
 	}
+	gnome_canvas_text_set_zoom_size(GNOME_CANVAS_TEXT(c_item), font_size);
 	g_debug("cria_slide_view_render_block(): showing canvas item");
 	gnome_canvas_item_show(c_item);
 	g_debug("cria_slide_view_render_block(): done");
@@ -634,6 +649,17 @@ cria_slide_view_render_blocks(CriaSlideView* self) {
 	g_free(blocks);
 }
 
+static void
+cria_slide_view_post_rendering(CriaSlideView* self) {
+	g_assert(self != NULL);
+	g_assert(CRIA_IS_SLIDE_VIEW(self));
+	g_assert(self->priv != NULL);
+	g_assert(self->priv->canvas != NULL);
+	g_assert(GNOME_IS_CANVAS(self->priv->canvas));
+
+	gnome_canvas_set_zoom(GNOME_CANVAS(self->priv->canvas), cria_slide_view_get_zoom(self));
+}
+
 static void
 cria_slide_view_slide_changed(CriaSlideView* self, gpointer data) {
 	g_assert(self != NULL);
@@ -642,6 +668,8 @@ cria_slide_view_slide_changed(CriaSlideView* self, gpointer data) {
 	cria_slide_view_clear_canvas(self);
 	cria_slide_view_render_background(self);
 	cria_slide_view_render_blocks(self);
+
+	cria_slide_view_post_rendering(self);
 }
 
 static void
